#[repr(u8)]pub enum Importance {
None = 0,
Min = 1,
Low = 2,
Default = 3,
High = 4,
}Expand description
How much the notifications of a Channel interrupt the user.
It maps to the NotificationManager.IMPORTANCE_* constants and is serialized as its
integer value. Only available on Android.
Variants
None = 0
The notifications are not shown.
Min = 1
The notifications are only shown in the shade, below the fold, without a status bar icon.
Low = 2
The notifications are shown without a sound.
Default = 3
The notifications are shown and make a sound.
This is the value used when the channel does not define an importance.
High = 4
The notifications are shown, make a sound and pop up as a heads-up notification.