Schedule

Enum Schedule 

pub enum Schedule {
    At {
        date: OffsetDateTime,
        repeating: bool,
        allow_while_idle: bool,
    },
    Interval {
        interval: ScheduleInterval,
        allow_while_idle: bool,
    },
    Every {
        interval: ScheduleEvery,
        count: u8,
        allow_while_idle: bool,
    },
}
Defines when a notification is delivered.

Scheduling is only implemented on mobile; the desktop implementation delivers the notification immediately and ignores the schedule.

Variants



At

Fires at a specific date and time, which must be in the future.

Fields

date: OffsetDateTime

The date and time the notification fires at, serialized as an ISO-8601 string.

repeating: bool

Whether the notification keeps repeating, using the duration between the moment it is scheduled and date as the interval. Defaults to false.

The interval must be at least one minute on iOS.

allow_while_idle: bool

Whether the notification is allowed to fire while the device is in low-power idle (Doze) mode. Defaults to false.

Only used on Android.



Interval

Fires whenever the current date matches every field set on the given interval.

Fields

interval: ScheduleInterval

The date fields the current date must match for the notification to fire.

allow_while_idle: bool

Whether the notification is allowed to fire while the device is in low-power idle (Doze) mode. Defaults to false.

Only used on Android.



Every

Fires repeatedly, once every count times the given interval unit.

Fields

interval: ScheduleEvery

The unit of the repeating interval.

count: u8

How many interval units elapse between each notification.

allow_while_idle: bool

Whether the notification is allowed to fire while the device is in low-power idle (Doze) mode. Defaults to false.

Only used on Android.