#[repr(i8)]pub enum Visibility {
Secret = -1,
Private = 0,
Public = 1,
}Expand description
How much of a notification is shown on the lock screen.
It maps to the Notification.VISIBILITY_* constants and is serialized as its
integer value. Only available on Android.
Variants
Secret = -1
The notification is not shown on the lock screen at all.
Private = 0
The notification is shown on the lock screen with its sensitive content hidden.
This is the value used when the channel does not define a visibility.
Public = 1
The notification is shown in full on the lock screen.