pub struct ActionTypeBuilder(/* private fields */);Expand description
Builder for an ActionType, created with ActionType::builder.
Implementations
Sourceimpl ActionTypeBuilder
impl ActionTypeBuilder
Sourcepub fn actions(self, actions: Vec<Action>) -> Self
pub fn actions(self, actions: Vec<Action>) -> Self
Sets the actions associated with this action type.
Sets the placeholder shown instead of the notification body when previews are hidden.
Only used on iOS.
Sourcepub fn custom_dismiss_action(self, custom_dismiss_action: bool) -> Self
pub fn custom_dismiss_action(self, custom_dismiss_action: bool) -> Self
Sets whether the app is notified when the user dismisses the notification.
Only used on iOS.
Sourcepub fn allow_in_car_play(self, allow_in_car_play: bool) -> Self
pub fn allow_in_car_play(self, allow_in_car_play: bool) -> Self
Sets whether the notification can be displayed in a CarPlay environment.
Only used on iOS.
Sets whether the notification title is shown even when previews are hidden.
Only used on iOS.
Sets whether the notification subtitle is shown even when previews are hidden.
Only used on iOS.
Sourcepub fn build(self) -> ActionType
pub fn build(self) -> ActionType
Builds the ActionType.