pub struct ChannelBuilder(/* private fields */);Expand description
Builder for a Channel, created with Channel::builder.
Only available on Android.
Implementations
Sourceimpl ChannelBuilder
impl ChannelBuilder
Sourcepub fn description(self, description: impl Into<String>) -> Self
pub fn description(self, description: impl Into<String>) -> Self
Sets the user visible description of the channel.
Sourcepub fn sound(self, sound: impl Into<String>) -> Self
pub fn sound(self, sound: impl Into<String>) -> Self
Sets the name of the sound resource played by the notifications of this channel.
The resource must be placed in the app’s res/raw folder.
Sourcepub fn lights(self, lights: bool) -> Self
pub fn lights(self, lights: bool) -> Self
Sets whether the notifications of this channel blink the device light.
Sourcepub fn light_color(self, color: impl Into<String>) -> Self
pub fn light_color(self, color: impl Into<String>) -> Self
Sets the color of the device light, as a color string such as #ff0000.
Sourcepub fn vibration(self, vibration: bool) -> Self
pub fn vibration(self, vibration: bool) -> Self
Sets whether the notifications of this channel vibrate the device.
Sourcepub fn importance(self, importance: Importance) -> Self
pub fn importance(self, importance: Importance) -> Self
Sets how much the notifications of this channel interrupt the user.
Sourcepub fn visibility(self, visibility: Visibility) -> Self
pub fn visibility(self, visibility: Visibility) -> Self
Sets how much of the notifications of this channel is shown on the lock screen.