NotificationBuilder

Struct NotificationBuilder 

pub struct NotificationBuilder<R: Runtime> { /* private fields */ }
The notification builder.

Implementations

Source

impl<R: Runtime> NotificationBuilder<R>

pub fn show(self) -> Result<()>

Shows the notification.

When no title was set with Self::title, the productName from the Tauri configuration is used instead. Only the title, body, icon and sound of the notification are used on desktop; the scheduling, grouping and action related options are ignored.

The notification is dispatched on a background task, so this returns as soon as the payload is prepared.

Errors

Returns an error when the notification could not be prepared, e.g. when the path of the running executable cannot be resolved on Windows.

Source

impl<R: Runtime> NotificationBuilder<R>

pub fn id(self, id: i32) -> Self

Sets the notification identifier.

pub fn channel_id(self, id: impl Into<String>) -> Self

Sets the identifier of the notification channel that delivers this notification.

If the channel does not exist, the notification won’t fire. Make sure the channel exists with Notification::list_channels and Notification::create_channel.

Only used on Android.

pub fn title(self, title: impl Into<String>) -> Self

Sets the notification title.

pub fn body(self, body: impl Into<String>) -> Self

Sets the notification body.

pub fn schedule(self, schedule: Schedule) -> Self

Schedule this notification to fire on a later time or a fixed interval.

pub fn large_body(self, large_body: impl Into<String>) -> Self

Multiline text. Changes the notification style to big text. Cannot be used with inboxLines.

pub fn summary(self, summary: impl Into<String>) -> Self

Detail text for the notification with largeBody, inboxLines or groupSummary.

pub fn action_type_id(self, action_type_id: impl Into<String>) -> Self

Defines an action type for this notification.

pub fn group(self, group: impl Into<String>) -> Self

pub fn group_summary(self) -> Self

Instructs the system that this notification is the summary of a group on Android.

pub fn sound(self, sound: impl Into<String>) -> Self

The sound resource name for the notification.

pub fn inbox_line(self, line: impl Into<String>) -> Self

Append an inbox line to the notification. Changes the notification style to inbox. Cannot be used with largeBody.

Only supports up to 5 lines.

pub fn icon(self, icon: impl Into<String>) -> Self

Notification icon.

On Android the icon must be placed in the app’s res/drawable folder.

pub fn large_icon(self, large_icon: impl Into<String>) -> Self

Notification large icon (Android).

The icon must be placed in the app’s res/drawable folder.

pub fn icon_color(self, icon_color: impl Into<String>) -> Self

Icon color on Android.

pub fn attachment(self, attachment: Attachment) -> Self

Append an attachment to the notification.

pub fn extra(self, key: impl Into<String>, value: impl Serialize) -> Self

Adds an extra payload to store in the notification.

pub fn ongoing(self) -> Self

If true, the notification cannot be dismissed by the user on Android.

An application service must manage the dismissal of the notification. It is typically used to indicate a background task that is pending (e.g. a file download) or the user is engaged with (e.g. playing music).

pub fn auto_cancel(self) -> Self

Automatically cancel the notification when the user clicks on it.

pub fn silent(self) -> Self

Changes the notification presentation to be silent on iOS (no badge, no sound, not listed).