Crate tauri_plugin_notification

Crate tauri_plugin_notification 

Send message notifications (brief auto-expiring OS window element) to your user. Can also be used with the Notification Web API.

Cargo features

  • windows7-compat: Deprecated and does nothing, since Tauri no longer supports Windows 7.

Structs

ActiveNotification
A notification that was delivered and is still visible in the notification center.
Attachment
A media file attached to a notification.
Notification
Access to the notification APIs.
NotificationBuilder
The notification builder.
NotificationData
The payload of a notification, as sent to the platform implementation.
PendingNotification
A notification that was scheduled and has not been delivered yet.
ScheduleInterval
The set of date fields a notification must match to be delivered.

Enums

Error
Errors returned by the notification plugin.
PermissionState
Permission state.
Schedule
Defines when a notification is delivered.
ScheduleEvery
The unit of the repeating interval used by Schedule::Every.

Traits

NotificationExt
Extensions to tauri::App, tauri::AppHandle, tauri::WebviewWindow, tauri::Webview and tauri::Window to access the notification APIs.

Functions

init
Initializes the plugin.

Type Aliases

Result
Alias for a std::result::Result with the error type set to Error.