Send message notifications (brief auto-expiring OS window element) to your user. Can also be used with the Notification Web API.
Cargo features
- windows7-compat: Deprecated and does nothing, since Tauri no longer supports Windows 7.
Structs
- Active
Notification - A notification that was delivered and is still visible in the notification center.
- Attachment
- A media file attached to a notification.
- Notification
- Access to the notification APIs.
- Notification
Builder - The notification builder.
- Notification
Data - The payload of a notification, as sent to the platform implementation.
- Pending
Notification - A notification that was scheduled and has not been delivered yet.
- Schedule
Interval - The set of date fields a notification must match to be delivered.
Enums
- Error
- Errors returned by the notification plugin.
- Permission
State - Permission state.
- Schedule
- Defines when a notification is delivered.
- Schedule
Every - The unit of the repeating interval used by
Schedule::Every.
Traits
- Notification
Ext - Extensions to
tauri::App,tauri::AppHandle,tauri::WebviewWindow,tauri::Webviewandtauri::Windowto access the notification APIs.
Functions
- init
- Initializes the plugin.
Type Aliases
- Result
- Alias for a
std::result::Resultwith the error type set toError.