Notification

Struct Notification 

pub struct Notification<R: Runtime>(/* private fields */);
Access to the notification APIs.

You can get an instance of this type via NotificationExt

Implementations

Source

impl<R: Runtime> Notification<R>

pub fn builder(&self) -> NotificationBuilder<R>

Creates a new builder for a notification.

Examples
use tauri_plugin_notification::NotificationExt;

fn notify<R: tauri::Runtime>(app: &tauri::AppHandle<R>) {
  app.notification()
    .builder()
    .title("Tauri")
    .body("Tauri is awesome!")
    .show()
    .unwrap();
}
pub fn request_permission(&self) -> Result<PermissionState>

Requests the permission to send notifications.

Desktop applications do not need to ask for this permission, so this always resolves to PermissionState::Granted without prompting the user.

pub fn permission_state(&self) -> Result<PermissionState>

Checks whether the permission to send notifications was granted.

Desktop applications do not need to ask for this permission, so this always resolves to PermissionState::Granted.