pub struct Notification<R: Runtime>(/* private fields */);Expand description
Access to the notification APIs.
You can get an instance of this type via NotificationExt
Implementations
Sourceimpl<R: Runtime> Notification<R>
impl<R: Runtime> Notification<R>
Sourcepub fn builder(&self) -> NotificationBuilder<R>
pub fn builder(&self) -> NotificationBuilder<R>
Creates a new builder for a notification.
Examples
use tauri_plugin_notification::NotificationExt;
fn notify<R: tauri::Runtime>(app: &tauri::AppHandle<R>) {
app.notification()
.builder()
.title("Tauri")
.body("Tauri is awesome!")
.show()
.unwrap();
}Sourcepub fn request_permission(&self) -> Result<PermissionState>
pub fn request_permission(&self) -> Result<PermissionState>
Requests the permission to send notifications.
Desktop applications do not need to ask for this permission,
so this always resolves to PermissionState::Granted without prompting the user.
Sourcepub fn permission_state(&self) -> Result<PermissionState>
pub fn permission_state(&self) -> Result<PermissionState>
Checks whether the permission to send notifications was granted.
Desktop applications do not need to ask for this permission,
so this always resolves to PermissionState::Granted.